﻿using System.Windows;
using System.Windows.Controls;
using System.Threading;
using System.Windows.Threading;
using System.Collections.ObjectModel;

namespace ComboDataForm
{
	public class DataSourceBehavior
	{
		public static bool GetEnable(DependencyObject obj)
		{
			return (bool)obj.GetValue(EnableProperty);
		}

		public static void SetEnable(DependencyObject obj, bool value)
		{
			obj.SetValue(EnableProperty, value);
		}

		public static readonly DependencyProperty EnableProperty =
			DependencyProperty.RegisterAttached("Enable", typeof(bool), typeof(DataSourceBehavior), new PropertyMetadata(OnEnabledPropertyChanged));

		private static void OnEnabledPropertyChanged(DependencyObject d, DependencyPropertyChangedEventArgs args)
		{
			// This will simulate the delay in the getting of the data source from a service

			DispatcherTimer timer = new DispatcherTimer();
			timer.Tick += (a, b) =>
			{
				// Case #1
				//var values = new IntVal[] 
				//{ 
				//    new IntVal() { ID = 1, Text = "one" },
				//    new IntVal() { ID = 2, Text = "two" },
				//    new IntVal() { ID = 5, Text = "five" },
				//    new IntVal() { ID = 10, Text = "ten" }
				//};
				//(d as ItemsControl).ItemsSource = values;

				// Case #2
				var values = new IntVal[] 
				{ 
				    new IntVal() { ID = 5, Text = "five" },
				    new IntVal() { ID = 1, Text = "one" },
				    new IntVal() { ID = 2, Text = "two" },
				    new IntVal() { ID = 10, Text = "ten" }
				};
				var source = new ObservableCollection<IntVal>();
				(d as ItemsControl).ItemsSource = source;
				foreach (var v in values)
				{
					source.Add(v);
				}



				timer.Stop();
			};
			timer.Interval = new System.TimeSpan(0, 0, 0, 0, 500);
			timer.Start();
		}
	}
}